/*
$Id$
    OWFS -- One-Wire filesystem
    OWHTTPD -- One-Wire Web Server
    Written 2003 Paul H Alfille
	email: paul.alfille@gmail.com
	Released under the GPL
	See the header file: ow.h for full attribution
	1wire/iButton system from Dallas Semiconductor
*/

#ifndef OW_STUB_H
#define OW_STUB_H

// VT: NOTE: This file serves the only purpose: so it can be checked by the
// packages that depend on this package. Other header files can't be used
// because they demand presence of config.h, or, rather, defined CONFIG_H.

#endif
